# -*- coding: utf-8 -*-

import unittest

from ant2mvn import utils


class TestUtils(unittest.TestCase):

    def test_mvn_sha1_search(self):
        f = utils.get_files('../resources/lib/', '.jar')[0]

        self.assertEqual(f, '../resources/lib/activation-1.1.jar')

        with open(f, 'rb') as file:
            s = utils.sha1(file.read())

            api = utils.MavenCentralRepoRestSearchApi('maven_central_repo', 'search.maven.org')
            r = api.sha1_search(s)

        self.assertEqual(r['response']['docs'][0]['id'], 'javax.activation:activation:1.1')


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-

from jinja2 import Environment, PackageLoader

import os
import re

from ant2mvn import utils


def jar2pom(jar_dir, local_dep_dir='lib', pom_options=None):

    if not pom_options:
        pom_options = {
            'project': {
                'groupId': 'com.example',
                'artifactId': 'artifact-example',
                'version': '1.0.0'
            },
            'repo': {
                'name': 'maven_central_repo',
                'host': 'search.maven.org'
            },
            'local_dependencies': {
                'default': {
                    'groupId': 'com.qq.utest.x',
                    'version': '1.0.0'
                }
            },
            'properties': {
                'project.packaging': 'jar',
                'project.build.finalName': '${project.artifactId}-${project.version}',
                'project.build.directory': 'target',
                'project.build.sourceDirectory': '${project.basedir}/src/main/java',
                'project.build.scriptSourceDirectory': 'src/main/scripts',
                'project.build.testSourceDirectory': '${project.basedir}/src/test/java',
                'project.build.outputDirectory': 'target/classes',
                'project.build.testOutputDirectory': '${project.build.directory}/test-classes',
                'project.build.sourceEncoding': 'UTF-8'
            },
            'resources': {
                'default': '${project.basedir}/src/main/resources',
                'test': '${project.basedir}/src/test/resources'
            }
        }

    jars = utils.get_files(jar_dir, '.jar')

    if len(jars) <= 0:
        return

    if not os.path.exists(local_dep_dir):
        os.makedirs(local_dep_dir)

    local_dep_pattern = re.compile(r"(.*?)-(\d[\.\-\w]*)\.jar")

    dependencies = []
    local_dependencies = []

    for jar_path in jars:
        with open(jar_path, 'rb') as jar_content:
            s = utils.sha1(jar_content.read())

            api = utils.MavenCentralRepoRestSearchApi(pom_options['repo']['name'], pom_options['repo']['host'])
            response = api.sha1_search(s)

            docs = response['response']['docs']

            if len(docs) > 0:
                d = docs[0]

                artifact = d.get('id').split(':')

                dependencies.append({
                    'groupId': artifact[0],
                    'artifactId': artifact[1],
                    'version': artifact[2],
                })
            else:
                local_jar_name = os.path.basename(jar_path)
                dest_jar_path = '%s/%s' % (local_dep_dir, local_jar_name)

                with open(dest_jar_path, 'wb') as lib:
                    lib.write(jar_content.read())

                g = pom_options['local_dependencies']['default']['groupId']
                p = dest_jar_path

                m = local_dep_pattern.match(local_jar_name)
                if m:
                    a = m.group(1)
                    v = m.group(2)
                else:
                    a = local_jar_name
                    v = pom_options['local_dependencies']['default']['version']

                local_dependencies.append({
                    'groupId': g,
                    'artifactId': a,
                    'version': v,
                    'path': p if p.startswith('/') else '${project.basedir}/%s' % p
                })

    env = Environment(loader=PackageLoader('ant2mvn', 'templates'))

    print(env.get_template('pom.xml.template').render(
        project={
            'groupId': pom_options['project']['groupId'],
            'artifactId': pom_options['project']['artifactId'],
            'version': pom_options['project']['version']
        },
        dependencies=dependencies,
        local_dependencies=local_dependencies,
        properties=pom_options['properties'],
        resources=pom_options['resources']
    ))




# -*- coding: utf-8 -*-

"""ant2mvn.

Usage: command_line.py <libs>
  --project.groupId=<project.groupId>
  --project.artifactId=<project.artifactId>
  --project.version=<project.artifactId>
  --local.dependencies.default.groupId=<local.dependencies.default.groupId>
  --local.dependencies.default.version=<local.dependencies.default.version>
  [--local.dependencies.dest=<local.dependencies.dest>]
  [--repo.name=<repo.name>]
  [--repo.host=<repo.host>]
  [--repo.port=<repo.port>]
  [--properties.project.packaging=<packaging>]
  [--properties.project.build.finalName=<finalName>]
  [--properties.project.build.directory=<directory>]
  [--properties.project.build.sourceDirectory=<sourceDirectory>]
  [--properties.project.build.scriptSourceDirectory=<scriptSourceDirectory>]
  [--properties.project.build.testSourceDirectory=<testSourceDirectory>]
  [--properties.project.build.outputDirectory=<outputDirectory>]
  [--properties.project.build.testOutputDirectory=<testOutputDirectory>]
  [--properties.project.build.sourceEncoding=<sourceEncoding>]
  [--resources.default=<resources.default>]
  [--resources.test=<resources.test>]

  command_line.py -h | --help
  command_line.py --version

Options:
  -h --help     Show this screen.
  --version     Show version.
  --repo.name=<repo.name>    Repository for searching [default: maven_central_repo].
  --repo.host=<repo.host>    Repository host [default: search.maven.org].
  --repo.port=<repo.port>    Repository port [default: 80].
  --local.dependencies.dest=<local.dependencies.dest>                       Local dependencies destication directory [default: lib].
  --properties.project.packaging=<packaging>                                Type of package [default: jar].
  --properties.project.build.finalName=<finalName>                          Name of package [default: ${project.artifactId}-${project.version}]
  --properties.project.build.directory=<directory>                          Build root directory [default: target].
  --properties.project.build.sourceDirectory=<sourceDirectory>              Source directory [default: ${project.basedir}/src/main/java].
  --properties.project.build.scriptSourceDirectory=<scriptSourceDirectory>  Script source directory [default: src/main/scripts].
  --properties.project.build.testSourceDirectory=<testSourceDirectory>      Test source directory [default: ${project.basedir}/src/test/java].
  --properties.project.build.outputDirectory=<outputDirectory>              Classes output directory [default: ${project.build.directory}/classes].
  --properties.project.build.testOutputDirectory=<testOutputDirectory>      Test classes output directory [default: ${project.build.directory}/test-classes].
  --properties.project.build.sourceEncoding=<sourceEncoding>                Source encoding [default: UTF-8].
  --resources.default=<resources.default>    Default resources root directory [default: ${project.basedir}/src/main/resources]
  --resources.test=<resources.test>          Test resources root directory [default: ${project.basedir}/src/test/resources]

"""
from docopt import docopt

from ant2mvn import logger
from ant2mvn import mvn


log = logger.get_logger(__name__)


def main():
    args = docopt(__doc__, version='1.0.0')
    log.debug(args)

    libs = args['<libs>']

    pom_options = {
        'project': {
            'groupId': args['--project.groupId'],
            'artifactId': args['--project.artifactId'],
            'version': args['--project.version']
        },
        'repo': {
            'name': args['--repo.name'],
            'host': args['--repo.host'],
            'port': args['--repo.port']
        },
        'local_dependencies': {
            'default': {
                'groupId': args['--local.dependencies.default.groupId'],
                'version': args['--local.dependencies.default.version']
            }
        },
        'properties': {
            'project.packaging': args['--properties.project.packaging'],
            'project.build.finalName': args['--properties.project.build.finalName'],
            'project.build.directory': args['--properties.project.build.directory'],
            'project.build.sourceDirectory': args['--properties.project.build.sourceDirectory'],
            'project.build.scriptSourceDirectory': args['--properties.project.build.scriptSourceDirectory'],
            'project.build.testSourceDirectory': args['--properties.project.build.testSourceDirectory'],
            'project.build.outputDirectory': args['--properties.project.build.outputDirectory'],
            'project.build.testOutputDirectory': args['--properties.project.build.testOutputDirectory'],
            'project.build.sourceEncoding': args['--properties.project.build.sourceEncoding']
        },
        'resources': {
            'default': args['--resources.default'],
            'test': args['--resources.test']
        }
    }

    mvn.jar2pom(libs, local_dep_dir=args['--local.dependencies.dest'], pom_options=pom_options)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

import logging

logging.basicConfig(
    level=logging.DEBUG,
    format='%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
    datefmt='%a, %d %b %Y %H:%M:%S',
    # filename='myapp.log',
    # filemode='w'
    )



# -*- coding: utf-8 -*-

import logging


logging.basicConfig(
    level=logging.DEBUG,
    format='%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
    datefmt='%a, %d %b %Y %H:%M:%S',
)


def get_logger(name):

    log = logging.getLogger(name)
    log.setLevel(logging.DEBUG)
    return log




# -*- coding: utf-8 -*-

from os.path import dirname, join
from setuptools import setup, find_packages


with open(join(dirname(__file__), 'ant2mvn/VERSION'), 'rb') as f:
    version = f.read().decode('ascii').strip()


setup(
    name='ant2mvn',
    version=version,
    url='http://techoffee.me',
    description='Making move Ant to Maven be easier',
    long_description=open('README.md').read(),
    author='Mario',
    maintainer='Mario',
    maintainer_email='hengliang.jia@gmail.com',
    license='MIT',
    packages=find_packages(exclude=('tests', 'tests.*')),
    include_package_data=True,
    zip_safe=False,
    entry_points={
        'console_scripts': ['ant2mvn = ant2mvn.command_line:main']
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    install_requires=[
        'docopt==0.6.2',
        'requests==2.11.1',
        'Jinja2==2.8'
    ],
)


# -*- coding: utf-8 -*-

import os
import hashlib
import requests

from ant2mvn import logger

log = logger.get_logger(__name__)

def get_files(path, file_extension=""):
    file_pathes = []

    for entry in os.scandir(path):
        if entry.name.endswith(file_extension) and entry.is_file():
            file_pathes.append(entry.path)

    return file_pathes


def sha1(data):
    s1 = hashlib.sha1()
    s1.update(data)
    return s1.hexdigest()


class MavenCentralRepoRestSearchApi(object):
    def __init__(self, name, host, port=80):
        self.name = name
        self.host = host
        self.port = port

        self.rest_search_api = {
            'sha1': 'http://%(host)s:%(port)s/%(api)s' % {
                'host': host,
                'port': str(port),
                'api': 'solrsearch/select'
            }
        }

    def sha1_search(self, sha1, rows=20):
        resp = requests.get(r'%(url)s?q=1:%(sha1)s&rows=%(rows)s&wt=%(wt)s' % {
            'url': self.rest_search_api.get('sha1'),
            'sha1': sha1,
            'rows': rows,
            'wt': 'json'
        })

        log.debug(resp.url)

        return resp.json()


